@@ -84,7 +84,7 @@
 #define PRISONSCANNER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PRISONSCANNER_NO_DEPRECATED
-#  define PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
+#  define PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
 #endif
 #ifdef PRISONSCANNER_NO_DEPRECATED_WARNINGS
 #  define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE 0x56b00
+#    define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE 0x56c00
 #  endif
 #endif
 
